==> jooby-pac4j-0.12.0-sources.jar: org/jooby/internal/pac4j/ConfigProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.jooby.internal.pac4j;

import java.util.Map;
import java.util.Map.Entry;

import javax.inject.Inject;
import javax.inject.Provider;

import org.pac4j.core.authorization.Authorizer;
import org.pac4j.core.client.Clients;
import org.pac4j.core.config.Config;

public class ConfigProvider implements Provider<Config> {

  private Config config;

  @SuppressWarnings("rawtypes")
  @Inject
  public ConfigProvider(final Clients clients, final Map<String, Authorizer> authorizers) {
    config = new Config(clients);
    for (Entry<String, Authorizer> entry : authorizers.entrySet()) {
      config.addAuthorizer(entry.getKey(), entry.getValue());
    }
  }

  @Override
  public Config get() {
    return config;
  }

}

==> jooby-pac4j-1.1.0-sources.jar: org/jooby/internal/pac4j/ConfigProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.jooby.internal.pac4j;

import java.util.Map;
import java.util.Map.Entry;

import javax.inject.Inject;
import javax.inject.Provider;

import org.pac4j.core.authorization.authorizer.Authorizer;
import org.pac4j.core.client.Clients;
import org.pac4j.core.config.Config;

public class ConfigProvider implements Provider<Config> {

  private Config config;

  @SuppressWarnings("rawtypes")
  @Inject
  public ConfigProvider(final Clients clients, final Map<String, Authorizer> authorizers) {
    config = new Config(clients);
    for (Entry<String, Authorizer> entry : authorizers.entrySet()) {
      config.addAuthorizer(entry.getKey(), entry.getValue());
    }
  }

  @Override
  public Config get() {
    return config;
  }

}
